;---------RESTORING BACKGROUND-------------------------  
DrawBackground
;restore background (pixels) behind jetman
	LD B,48						;height in lines
	LD (StoreStack),SP
		
	
	LD SP,BackgroundBuffer2


;draw one line of background

DrawBackground1
	POP HL					;address of next pixel line into HL
	
	POP DE					;read 2 bytes of background data
	LD (HL),E
	INC L
	LD (HL),D
	INC L
	POP DE					;restore next 2 bytes of background data
	LD (HL),E
	INC L
	LD (HL),D				;4 bytes in a line are done
	
	DJNZ DrawBackground1
	
	LD SP,(StoreStack)	
	
;----------	
RestoreJetmanBackAttr
;should we deal with jetman attr at all?
	LD A,(JetmanAttrs)
	OR A
	RET NZ					;do not use jetman attributes was chosen in menu

;restore colors of background behind jetman
	LD HL,(OldJetmanAttrPos)
	LD BC,BackgroundAttrBuffer
	LD DE,29
 
	EXX
	LD B ,6 				;height in alternate register
RestoreJetmanBackAttr2 
	EXX
	
	LD  A,(BC) 				;one line(repeat 4 times) 
 	LD (HL),A
	INC  C
	INC  L
 
	LD  A,(BC)
	LD  (HL),A
	INC  C
	INC  L
	
	LD  A,(BC)
	LD  (HL),A
	INC  C
	INC  L
 
	LD  A,(BC)
	LD  (HL),A
	INC  C
 	
	ADD HL,DE				;HL=HL+29 (go to next line of attributes)
							;HL was already increased by 3 so it is now incresed by 32(next line)
	EXX
 	DJNZ RestoreJetmanBackAttr2 	;decrease B from alternate register
 	
 	EXX								;normal registers
	RET
	
;--------------------------- 
PrepareBackgroundForDrawing
;we must enable fast background restoring after HALT (without that the game will flicker)
;to do that we must mix background data with addresses where they will be placed
;the data structure is: address of pixel line and 4 bytes in this line
;such data can be read quickly using stack
	DI
	LD HL,(OldJetmanPos)		;screen address of left upper corner of background position
	LD DE,BackgroundBuffer2		;buffer to store background mixed with address lines
	LD IX,BackgroundBuffer
	LD B,48						;number of lines

PrepareBackgroundForDrawing2	
	LD A,L
	LD (DE),A
	INC DE
	LD A,H
	LD (DE),A
	INC DE						;store line address (2 bytes)
	CALL OnePixelLineDown
	
	REPT 4
	LD A,(IX+0)					;store graphics (4 bytes)
	LD (DE),A
	INC DE
	INC IX
	ENDR
	DJNZ PrepareBackgroundForDrawing2
	
	EI
	RET	
 
	
 ;-------DRAWING JETMAN SPRITE AND STORING BACKGROUND-------------- 
DrawJetman
;draw jetman (pixels and store background behind him)
	LD HL,BackgroundBuffer		;background buffer address
	LD B,48						;height in lines
	LD (StoreStack),SP
	LD SP,JetmanNewLineAdresses	;start of line addresses
 	LD C,H			;high byte of background buffer
 	
DrawJetman2
	POP DE			;address of next pixel line into HL
		
	
	REPT 3			;4 bytes in a line. now repeat 3 times
;Background 
	LD  A,(DE)		;read background
	LD (HL),A 		;store background In buffer 
	INC  H 			;go to mask buffer 

;Mask 
	AND  (HL) 		;combine background with mask
	INC  H 			;go to sprite buffer 
 
;Sprite 
	OR  (HL)	 	;combine sprite data with mask and background
	LD  (DE),A 		;put it into screen 
	INC  E 			;next collumn 
	INC L 			;next data byte (no possibility of carry, so no need INC HL) 
	LD H,C 			;back to background buffer 
 	ENDR
 
;the forth byte goes the same but without one INC E
	LD  A,(DE)
	LD (HL),A 		;store background In buffer 
	INC  H 			;go to mask buffer 

;Mask 
 	AND  (HL) 		;combine mask with background 
 	INC  H 			;go to sprite buffer 

;Sprite 
 	OR  (HL)		;combine sprite with mask and background
 	LD  (DE),A 		;put it into screen 
 	;no INC E here 
 	INC L 			;next data byte (no possibility of carry, so no need INC DE) 
 	LD H,C			;back to background buffer
 	
 	DJNZ DrawJetman2	
	
 	LD SP,(StoreStack)
	RET 

;----------DRAWING JETMAN COLORS AND STORIN BACKGROUND COLORS------------------
DrawJetmanAttr
;should we deal with jetman attributes at all?
	LD A,(JetmanAttrs)
	OR A
	RET NZ					;do not use jetman attributes was chosen in menu
	
;store colors of background behind jetman and write jetman attributes
;jetman is white but if only a small part of his body covers the attribute square
;the attribute remains unchanged to prevent color clash

	LD  HL,(NewJetmanAttrPos)
	LD  DE,BackgroundAttrBuffer
	

;---------
;determine depending on rotation, facing left/right and x position
;which pattern of attributes should be used 
;rotation 0 OR 2=pattern1, rotation 4 OR 6=pattern2 
 
	LD IX,JetmanAttr1			;default attribute patterm
	LD A,(StandingStatus)
	OR A
	JR Z,DrawJetmanAttrs1		;use default pattern for standing sprite
	
;facing left or right	
	LD  A,(FacingDir)			
	CP  1 						
	JR Z,AttrPattern_Right

AttrPattern_Left				
	LD A,(JetmanRotation)
	CP 5
	JR C,DrawJetmanAttrs1
	LD IX,JetmanAttr2L
	JR DrawJetmanAttrs1
	
AttrPattern_Right					
	LD A,(JetmanRotation)
	CP 3
	JR NC,DrawJetmanAttrs1
	LD IX,JetmanAttr2R			;pattern for rotation 0 or 2 facing right	
	

		
DrawJetmanAttrs1
	LD A,(JetmanY)		;adjust attributes for the jetman if he is flying
	AND 00000111b				;extract last three bits from Y position -> number 0-7
	CP 3						;if number is <3 -> jetman is more or less at equal attribute position, use tha same pattern as for standing
	JR C,DrawJetmanAttrs2

	DEC IX						;change attribute pattern
	DEC IX						;make first row of attributes empty (go to .BYTE 0,0,0,0) -> don't draw attributes
	DEC IX						;do that to minimalise color clash
	DEC IX

DrawJetmanAttrs2
	LD C ,6						;jetman char height 
	

DrawJetmanAttrs3
	LD B,4						;jetman may be 4 chars wide but we are modifying only 3 chars wide
	PUSH  HL
 
DrawJetmanAttrs4 
;one attribute 
	LD  A,(HL)
	LD  (DE),A 					;store background attribute 
	LD  A,(IX+0)				;read jetman attribute (white or nothing)
	OR  A
	JR  Z,DrawJetmanAttrs5		;skip jetman attribute if necessary 
 
	LD  A,(HL)
	AND  11111000b 				;extract background paper 
	OR  01000111b 				;white color bright 
	LD  (HL),A					;write jetman attribute
DrawJetmanAttrs5 
	INC  DE
	INC  L
	INC  IX
	DJNZ DrawJetmanAttrs4		;one line of attributes
 
	POP  HL
	PUSH DE					
	LD DE,32					;go one line down
	ADD HL,DE
	POP DE
	
	DEC  C
	JR  NZ,DrawJetmanAttrs3		;repeat if there are still lines to do
	RET 

	
;-------------------MAKING MIRRORS OF ALL JETMAN FRAMES----------------------	
MirrorJetman
;make a mirror image of all jetman sprites
 	
	LD  HL,Jetman1M			;address of first frame - start of jetman data
	LD  C,30  				;number of frames to rotate (mask and sprite are counted as 2 frames)

MirrorJetman2
	LD  B,48 				;number of lines in one frame
	PUSH  HL
	CALL MirrorLine
	POP  HL
	LD  DE,144 				;go to next frame - add frame size
	ADD  HL,DE
	DEC  C
	JR  NZ, MirrorJetman2
 
	RET   					;end of mirroring 
	
	
;-------------------------------- 
MirrorLine
	LD  A,(HL)
	CALL  Mirrorbyte
	LD E,A					;rotate left byte and store it in E 
	INC  HL
	LD  A,(HL)
	CALL Mirrorbyte 		;rotate middle byte 
	LD  (HL),A   			;and write it 
	INC  HL
	LD  A,(HL)
	CALL  Mirrorbyte 		;rotate right byte 
	LD  D,A 				;store right byte 
	LD  A,E
	LD  (HL),A 				;write left byte to right byte 
	DEC  HL
	DEC  HL
	LD  A,D
	LD  (HL),A 				;write right byte to left byte 
	INC  HL
	INC  HL
	INC  HL 				;go to next next 3 byte wide line 
	DJNZ  MirrorLine 		;repeat B times 
	RET 
 
;-------------
Mirrorbyte
		LD D,0
		RLCA
		RR D
		RLCA
		RR D
		RLCA
		RR D
		RLCA
		RR D
		RLCA
		RR D
		RLCA
		RR D
		RLCA
		RR D
		RLCA
		RR D
		LD A,D
		RET
		
;---------PREPARING JETMAN SPRITE IN BUFFER------------- 
PrepareJetman
;prepare (put into buffer) sprite number B  

FindMaskAddress
 LD  HL,Jetman1M-288
 LD  DE,144
FindMaskAddress2
 ADD  HL,DE
 ADD  HL,DE
 DJNZ  FindMaskAddress2
 EX DE,HL  					;mask address found and placed in DE   

;put mask into buffer 
 PUSH  BC
 PUSH  DE
 CALL  MaskIntoBuffer 
 POP  DE
 POP  BC
 
;put sprite into buffer 
 EX  DE,HL
 LD  DE,144
 ADD  HL,DE
 EX  DE,HL  				;now DE contains sprite address 

 CALL  SpriteIntoBuffer
 RET   

;----------------------
MaskIntoBuffer
;DE should contain adress of mask data 

 LD  HL, MaskBuffer
 LD  B,48 					;number of lines 
 
 
;Write mask into work buffer 
;start of mask data in DE,start of buffer in HL,nr of lines to be put into buffer in B 

MaskIntoBuffer2
 REPT 3						;Original mask size(without 4th byte which will be added later)= nr of bytes per line 
 LD  A,(DE) 
 LD  (HL),A 				;write one line to buffer
 INC L 						;next buffer address (no need of doing INC HL) 
							;cause there is no posibility of carry) 
 INC  DE
 ENDR
 
 LD  (HL),255 				;empty 4th column- right side of sprite 
 INC  L
 DJNZ MaskIntoBuffer2		;repeat 48 times

;mask is in buffer now it is time to rotate it 
RotateMask
 LD  A,(JetmanRotation)
 LD  C,A					;number of pixels to rotate mask in C
 OR  A
 RET Z 						;if no rotation required , just return 

;set rotating parameter 
 LD  HL,RotateOption
 LD  (HL),0 				; when rotating left side of buffer is filled with lit pixels(SCF NOP) 
 

RotateMask1
 LD  HL,MaskBuffer 			;start of rotated mask data 
 LD  B,48 					;number of lines  
 CALL  RotateRight 			;makes one rotation 
 DEC  C
 JR  NZ, RotateMask1 		;make C rotations 
 RET 
  
;------------------
SpriteIntoBuffer
;DE should cotain adress of sprite data 

 LD  HL, SpriteBuffer
 LD  B,48					;number of lines 
  
;write sprite into work buffer 
;start of sprite data in DE, start of buffer in HL,nr of lines to be put into buffer in B
 
SpriteIntoBuffer2
 REPT 3 					;Original mask size(without 4th byte which will be added later)
 LD  A,(DE) 
 LD  (HL),A 				;write one line to buffer 
 INC L 						;next buffer address (no need of doing INC HL) 
  							;cause there is no posibility of carry) 
 INC  DE
 ENDR
 
 LD  (HL),0 				;empty 4th column - right side of sprite 
 INC  L
 DJNZ SpriteIntoBuffer2		;repeat 48 times
 
;sprite is in buffer, now it is time to rotate it 
RotateSprite
 LD  A,(JetmanRotation)
 LD  C,A					;number of pixels to rotate mask in C
 OR  A
 RET Z 						;if no rotation required, just return 

;set rotating parameter 
 LD  HL,RotateOption
 LD (HL),63 				;when rotating left side of buffer is being filled with unlit pixels (SCF CCF(code 63)) 

RotateSprite1
 LD  HL,SpriteBuffer 		;start of rotated mask data 
 LD  B,48 					;number of lines  to rotate
 CALL  RotateRight 			;make one line rotation 
 DEC  C
 JR  NZ, RotateSprite1 		;makes C rotations 
 RET	
	
;---------------------------
RotateRight
;rotate graphical data in buffer right one pixel
;HL: start of buffer
;B: of lines to rotate		 

 
RotateRight2
	SCF  
RotateOption
	.BYTE 0  				;when rotating sprite carry flag should be set to 0 
     						;because we put empty space left of sprite 
     						;but when rotating mask it should be set to 1 
     						;because only centre of mask is empty and borders are of filled space 
     						;so RotateOption cell shuold contain either nop commands which leaves carry as 1 
     						;(set by previous command SCF) of CCF command which changes it to 0 
     						;RotateOption cell is changed by another routine, so it is self modifying code   

 
	RR  (HL)					;rotate right  one line
	INC  L
	RR  (HL)
	INC  L
	RR  (HL)
	INC  L
	RR  (HL)
	INC  L
	DJNZ  RotateRight2 		;repeat B times
	RET
	
;--------------------------- 
XYtoHL
;turn XY into HL screen coordinates
;B contains X, C contains Y 
 
 LD  A,C
 AND  00000111b
 LD  H,A
 LD  A,C
 RRA 
 RRA 
 RRA 
 AND  00011000b
 OR  H
 OR  01000000b
 LD  H,A
 
 LD  A,B
 RRA 
 RRA 
 RRA 
 AND  00011111b
 LD  L,A
 LD  A,C
 RLA 
 RLA 
 AND  11100000b
 OR  L
 LD  L,A
 RET 

;--------------------------- 
CountAttrPos
;using jetman graphics screen position counts jetman attribute position
	LD HL,(NewJetmanPos)
	LD  A,H
	AND  11111000b
	LD  H,A
	LD  A,80
	SRL  H
	SRL  H
	SRL  H
	ADD  A,H
	LD  H,A 
	LD (NewJetmanAttrPos),HL	
	RET