DrawRoom
;HL: room data address 
		
	LD (CurrentLocation),HL				;store start of current room data to proper cell
	
	PUSH HL
	CALL ClearPlayingScreen
	POP HL								;restore room data address
		
	LD A,64
	LD (WhichSegment),A			
		
;drawing tile blocks		
RoomBlock1
		LD A, (HL)						;number of tile loaded in A
		OR A
		JR Z, RoomBlock2				;if (HL)=0 that means either end of drawing blocks
										;or going to next of three screen blocks
										; (increasing H by 8)
		
		CALL CountTileAddress			;counts address of tile graphics and put it in DE
		
		INC HL 
		LD A,(HL)
		LD B,A
		INC HL
		LD A,(HL)
		LD C,A							;BC is loaded with block size
				
		INC HL
										;HL containing  room data address stored
		LD A,(HL)			
		
		PUSH HL		
		LD L,A							;HL is loaded with block
		LD A, (WhichSegment)			;left upper corner
		LD H,A	
	
		CALL TileBlock					;call block drawing routine drawing a block	of tiles
		
		POP HL							;restore room block data address in HL
		INC HL							;start of next block
		JR RoomBlock1
		
;go to next screen part / end drawing blocks		
RoomBlock2
		INC HL							;go to next byte of room data
		LD A,(WhichSegment)
		CP 80							;checks if last screen part
		JR Z, RoomTile1 				;if so end drawing blocks
		ADD A,8							;if not go to another screen part
		LD (WhichSegment),A
		JR RoomBlock1

				
;draw single tiles
RoomTile1
		LD A,64
		LD (WhichSegment),A
		
RoomTile2
		LD A, (HL)						;number of tile	loaded IN A
		
		OR A
		JR Z, RoomTile3					;if (HL)=0 that means either end of drawing tiles
										;or going to next of three screen segments
										;(increasing H by 8)
		
		CALL CountTileAddress			;count address of tile graphics and put it in DE

		INC HL
		PUSH HL							;store room data address
		LD A, (HL)
		LD L,A
		LD A, (WhichSegment)
		LD H,A							;position into HL
					
		CALL DrawTile					;draw the tile
		
		POP HL							;restore room data address
		INC HL							;go to next room data byte
		JR RoomTile2
					
RoomTile3	
		INC HL							;go to next byte of room data
		LD A,(WhichSegment)
		CP 80							;check if last screen part
		JR Z, RoomCode 				;if so end drawing tiles
		ADD A,8							;if not go to another screen part
		LD (WhichSegment),A
		JR RoomTile2
		
		
;-------------------
RoomCode
 PUSH HL
 CALL DoLocationCode					;perform code specific for our location (if it exists)	
 POP HL 								;(draw doors,animations, etc)
 
RoomItems
 PUSH HL
 CALL PrepareItems
 CALL DrawItems
 POP HL			
 
RoomEnemies
 LD A,(UpdateEnemy)						;should enemy data be read from location data (it shouldn't if we are refreshing current location)
 OR A
 CALL NZ, SetEnemy
 LD A,1
 LD (UpdateEnemy),A						;default setting is yes, update enemy when drawing a location

 RET
		

;----------------------------------
TileBlock
;draw block of tiles
;HL position of left upper corner
;BC block size
;DE tile address in memory		
		
TileBlock1
		PUSH BC
		PUSH DE
		PUSH HL

;draw one horizontal line of tiles
TileBlock2	PUSH BC
			PUSH DE
			PUSH HL
			CALL DrawTile			;draw a single tile

			POP HL
			POP DE					;restore screen position and start address of data
	
			LD A,(DE)
			LD B,A					;read tile width from memory and write to B
	
			LD A,L
			ADD A,B
			LD L,A					;count horizontal coordinate of next tile in the line
	 								;(Add B=tile size to coordinate of previous tile)
			
			POP BC					;write block size to BC
									;decrease number of tiles in the line left to do
			DJNZ TileBlock2
		
; draw C lines of tiles
	POP HL
	POP DE
	
	INC DE
	LD A,(DE)						;read tile height from memory
	LD C,A							;write tile height to C	
	DEC DE	
	
		LD B,L						;B is used to check carry		
		LD A,L	
TileBlock3	
		ADD A,32 					;go C lines down,because C=tile height
		DEC C
		JR NZ, TileBlock3
		LD L,A						;change vertical position to next collumn of tiles (moves it C chars down)
		
		;checks if new tile begins in next of three screen segments
		;carry appears when L<B(number exceeded 256)
		;A contains already L
		
		SUB B	
		JR NC, TileBlock4				;if no carry, just do nothing
		LD A,H
		ADD A,8
		LD H,A						;if carry change address properly
				
TileBlock4	
		POP BC						;write block size to BC
		DEC C						;decrease number of columns left to do
		JR NZ, TileBlock1	
		RET
		
;--------------------------------------
; draw a single tile  on the screen

;HL contains address of the upper left corner of the tile		
;BC contains size of the tile (it is read by this rOUTine)
;DE contains start address of tile IN memory	

;empty chars (chars with all 8 bytes equal to 0) are coded with just one byte to save space, number 16 is used
;first byte of 8 bytes in a char cannot be 16, because program will interpret it as an empty square!!!
		
DrawTile
;First 2 sprite bytes contain size of the sprite
;BC register is loaded with size

	LD A,(DE)
	LD B,A 							;x width
	INC DE
	LD A,(DE)
	LD C,A 							;y-height	
	INC DE			
	
DrawTile0				
; store screen tile address - HL and its size-BC for further use by attributes routine
	PUSH HL
	PUSH BC			
						
		
;this loop draw "C" lines of chars
DrawTile1	PUSH HL
			PUSH BC
		
;this loop draws one line of chars
DrawTile2					
			LD C,H				;store H
			LD A, (DE)
			CP 16	  			;16-empty char code, when it is detected program jumps to another char.It saves data space	
			JR NZ, DrawTile3	;when first byte is not 16 should draw A char
			
			INC DE 				; when an empty char happens,; so skip it and go to next char 
			JR DrawTile4 
							
					

DrawTile3			
				LD A, (DE)		;draw one char
					LD (HL),A 	;repeated 8 times, quicker than A loop
					INC H
					INC DE
				LD A, (DE)
					LD (HL),A
					INC H
					INC DE
				LD A, (DE)
					LD (HL),A
					INC H
					INC DE
				LD A, (DE)
					LD (HL),A
					INC H
					INC DE
				LD A, (DE)
					LD (HL),A
					INC H
					INC DE
				LD A, (DE)
					LD (HL),A
					INC H
					INC DE
				LD A, (DE)
					LD (HL),A
					INC H
					INC DE
				LD A, (DE)
					LD (HL),A
					INC DE
						
DrawTile4		
				LD H,C			;restore H
				INC L			;go one char right  
				DJNZ DrawTile2 
				
			POP BC
			POP HL				
			LD A,L
			ADD A,32			;go to another line of chars 
			LD L,A
			JR NC,DrawTile5		;not carry=no going to next segment, so no H changes needed
				
			LD A,H				;change H only if going to next screen segment
			ADD A,8
			LD H,A
					
DrawTile5			
			DEC C				;decrease number of char lines left to do
			JR NZ, DrawTile1
		
;drawing tile is finished
;now restore size of the tile IN BC, its corner IN HL
; DE is already increased to next byte where attributes data begin
						
		POP BC
		POP HL		
						
;ATTRIBUTES
;BC should contain sprite size (B-width C-height)
;DE should contain start of attributes data		
;HL should contain address of firt byte of attr		
	
;Transform point address to attribute address
		
TileAttrs		
		LD A,80
		SRL H
		SRL H
		SRL H
		ADD A,H
		LD H,A
			
;draw C lines of attributes
TileAttr1
	 	PUSH BC
		PUSH HL
		
;draw one line of attributes
TileAttr2
		LD A,(DE)
		OR A				;check if attribute is set to 0
		JR Z, TileAttr3		;if so dont draw attributes AND leave the square as it is
		LD (HL),A
TileAttr3
		INC HL				;go to next square IN the row
		INC DE
		DJNZ TileAttr2
	
		POP HL
		PUSH DE 			;go to next row of attributes
		LD DE,32
		ADD HL,DE
		POP DE
		POP BC
		DEC C				;decrease number of lines left to do 
		JR NZ, TileAttr1
		RET

;-----------------------------
CountTileAddress	
	LD BC,TileAddrData-2
CountTileAddress2
	INC BC
	INC BC
	DEC A
	JR NZ,CountTileAddress2		

	LD A,(BC)				;position of tile address in memory placed in BC	
	LD E,A
	INC BC
	LD A,(BC)
	LD D,A					;tile address placed IN DE
	RET
;-----------
FindRoom
;take number of room in A amd return adrress of room in HL
 LD E,A
 LD D,0
 LD HL,RoomsList-2
 ADD HL,DE		
 ADD HL,DE					;address of address:) IN HL
 LD E,(HL)
 INC HL
 LD D,(HL)
 EX DE,HL					;adress of room IN HL						
 RET				

 
 
;-------------------------
ClearScreen
	XOR A
	OUT (254),A

;clear whole screen
;doesn't need to be fast
	LD HL,16384
	LD (HL),A
	LD DE,16385
	LD BC,6143
	LDIR
	
	
	LD A,71
	LD HL,22528
	LD (HL),A
	LD DE,22529
	LD BC,767
	LDIR
			
	RET	

;-------------------------	
ClearPlayingScreen
	DI
	LD (StoreSp),SP
	LD DE,0
	
;clear bottom half of top screen segment
	LD HL,16384+128+128
		
	LD C,8
ClearPlayingScreen2		
	LD SP,HL
	LD B,4							;do 128 bytes - 4 pixel lines in 4 character lines
ClearPlayingScreen3	
	REPT 16
	PUSH DE
	ENDR
	DJNZ ClearPlayingScreen3	
	
	INC H							;go to next of 8 pixel lines in character line
	DEC C
	JR NZ,ClearPlayingScreen2	
	
;clear bottom 2/3 of screen
	LD DE,0
	LD SP,16384+6144
	LD B,128
ClearPlayingScreen4
	REPT 16
	PUSH DE
	ENDR
	DJNZ ClearPlayingScreen4		
	
;attributes
	LD SP,22528+768					;end of attributes 
	LD B,40 						;clear 40*8 PUSH DE*2 bytes per DE=640 bytes (20 lines)
	LD DE,71*256+71
ClearPlayingScreen5
	REPT 8
	PUSH DE
	ENDR		
	DJNZ ClearPlayingScreen5
	
	LD SP,(StoreSp)
	EI		
	RET
	
StoreSp .WORD 0

;---------------
OneScreenRight
 LD HL,CurrentRoomNr
 INC (HL)						;change room								
 LD A,(HL)
 CALL FindRoom
 CALL DrawRoom
 XOR A 							;change position place -> jetman at left edge of new screen
 LD (JetmanX),A
 JR ChangeRoom

;---------------
OneScreenLeft
 LD HL,CurrentRoomNr
 DEC (HL)						;change room								
 LD A,(HL)
 CALL FindRoom
 CALL DrawRoom
 LD A,222						;change position place -> jetman at right edge of new screen
 LD (JetmanX),A
 JR ChangeRoom
 
;---------------		
OneScreenDown
 LD HL,CurrentRoomNr
 LD A,(HL)
 ADD A,16						;nr of room+16=nr of room down
 LD (HL),A						;change room								
 CALL FindRoom
 CALL DrawRoom
 LD A,32						;change position -> place jetman at top of new screen
 LD (JetmanY),A
 JR ChangeRoom
 
;---------------		
OneScreenUp
 LD HL,CurrentRoomNr
 LD A,(HL)
 CP 17							;check if jetman is in one of topmost 16 screens (nr<17)
 JR NC,OneScreenUp2 	
 
 LD HL,JetmanY					;if so don't update screen and modify y coordinate
 INC (HL)
 INC (HL)
 JP WalkEnd	
	 				
OneScreenUp2		
 SUB 16							;nr of room-16=nr of room up
 LD (HL),A						;change room								
 CALL FindRoom
 CALL DrawRoom
 LD A,136						;change position -> place jetman at bottom of new screen
 LD (JetmanY),A
 JR ChangeRoom
		
;---------------						
ChangeRoom		
 LD HL,JetmanX
 LD B,(HL)     					;modify jetman position,old position, and attr positions
 INC HL
 LD C,(HL)
 CALL XYtoHL
 LD (NewJetmanPos),HL		
 LD (OldJetmanPos),HL
 
;prepare line addresses of jetman lines
	LD DE,JetmanNewLineAdresses
	LD B,48
	CALL PrepareLineAddressesInBuffer
	
ChangeRoom2
 LD HL,(NewJetmanPos) 
 DI								;interrupt shouldn't happen now, when drawing jetman
 CALL DrawJetman				;draw jetman in new room and forget the background from old room
 CALL PrepareBackgroundForDrawing
 
 		
 CALL CountAttrPos
 LD (OldJetmanAttrPos),HL			
 CALL DrawJetmanAttr
 EI
  							
 RET 								

;--------
RoomsList
	.WORD Loc_A01
	.WORD Loc_A02
	.WORD Loc_A03
	.WORD Loc_A04
	.WORD Loc_A05
	.WORD Loc_A06
	.WORD Loc_A07
	.WORD Loc_A08
	.WORD Loc_A09
	.WORD Loc_A10
	.WORD Loc_A11
	.WORD Loc_A12
	.WORD Loc_A13
	.WORD Loc_A14	
	.WORD Loc_A15
	.WORD Loc_A16
			
	.WORD Loc_B01
	.WORD Loc_B02
	.WORD Loc_B03
	.WORD Loc_B04
	.WORD Loc_B05	
	.WORD Loc_B06
	.WORD Loc_B07	
	.WORD Loc_B08
	.WORD Loc_B09			
	.WORD Loc_B10	
	.WORD Loc_B11
	.WORD Loc_B12
	.WORD Loc_B13
	.WORD Loc_B14
	.WORD Loc_B15
	.WORD Loc_B16

					
	.WORD Loc_C01
	.WORD Loc_C02
	.WORD Loc_C03
	.WORD Loc_C04
	.WORD Loc_C05
	.WORD Loc_C06
	.WORD Loc_C07
	.WORD Loc_C08
	.WORD Loc_C09
	.WORD Loc_C10	
	.WORD Loc_C11
	.WORD Loc_C12
	.WORD Loc_C13
	.WORD Loc_C14	
	.WORD Loc_C15
	.WORD Loc_C16
	
		
	.WORD Loc_D01
	.WORD Loc_D02
	.WORD Loc_D03
	.WORD Loc_D04
	.WORD Loc_D05
	.WORD Loc_D06
	.WORD Loc_D07
	.WORD Loc_D08	
	.WORD Loc_D09
	.WORD Loc_D10
	.WORD Loc_D11
	.WORD Loc_D12	
	.WORD Loc_D13	
	.WORD Loc_D14	
	.WORD Loc_D15
	.WORD Loc_D16

				
	.WORD Loc_E01
	.WORD Loc_E02
	.WORD Loc_E03
	.WORD Loc_E04
	.WORD Loc_E05
	.WORD Loc_E06
	.WORD Loc_E07
	.WORD Loc_E08
	.WORD Loc_E09
	.WORD Loc_E10
	.WORD Loc_E11
	.WORD Loc_E12
	.WORD Loc_E13
	.WORD Loc_E14
	.WORD Loc_E15
	.WORD Loc_E16
			
			
	.WORD Loc_F01
	.WORD Loc_F02
	.WORD Loc_F03
	.WORD Loc_F04
	.WORD Loc_F05
	.WORD Loc_F06
	.WORD Loc_F07
	.WORD Loc_F08
	.WORD Loc_F09
	.WORD Loc_F10
	.WORD Loc_F11
	.WORD Loc_F12
	.WORD Loc_F13
	.WORD Loc_F14
	.WORD Loc_F15
	.WORD Loc_F16

	.WORD Loc_G01
	.WORD Loc_G02
	.WORD Loc_G03
	.WORD Loc_G04
	.WORD Loc_G05
	.WORD Loc_G06
	.WORD Loc_G07
	.WORD Loc_G08
	.WORD Loc_G09
	.WORD Loc_G10
	.WORD Loc_G11
	.WORD Loc_G12
	.WORD Loc_G13
	.WORD Loc_G14
	.WORD Loc_G15
	.WORD Loc_G16
				
	.WORD Loc_H01
	.WORD Loc_H02
	.WORD Loc_H03
	.WORD Loc_H04
	.WORD Loc_H05
	.WORD Loc_H06
	.WORD Loc_H07
	.WORD Loc_H08
	.WORD Loc_H09
	.WORD Loc_H10
	.WORD Loc_H11
	.WORD Loc_H12
	.WORD Loc_H13
	.WORD Loc_H14
	.WORD Loc_H15
	.WORD Loc_H16
;----
WhichSegment	.BYTE 0	
CurrentLocation	.WORD 0
UpdateEnemy 	.BYTE 1		;when drawing a new location it is necessary to read enemy data
							;but when refreshing a location, the player is already in, it isn't necessary
					
