;------------------			
InitialiseItems
;copy initial item data to game item data
	LD HL,InitialItemData
	LD DE,ItemData
	LD BC,22*5				;number of items*5 bytes for each item
	LDIR
	RET	

;------------------------------
PrepareItems
	
;prepare list of items in current location	
	LD A,1
	LD (CurrentItemNr),A

	
;the table structure is as follows:
	;number of item - 1 byte
	;position where player should stand to pick up item, 2 bytes	

;---------------------------	
;clear data table with info about items in current room;
	XOR A
	LD (CurrentRoomItemsNr),A			;set number of items in current location to 0
	
	LD B,14								;2 items X 7 bytes per items
	LD HL,CurrentLocationItemTable			
ClearItemDataTable
	LD (HL),A
	INC HL
	DJNZ ClearItemDataTable		
;---------------------------	
	
 	LD IX,CurrentLocationItemTable		;start of table where data about items in current room are stored
	LD HL,ItemData						;start of data about items in current game							
			
PrepareItems2
;read info about next item
	LD A,(HL)							;check if end of item list		
	OR A								;0 means end of item list,else location number is read
	RET Z								;item preparing is finished
					
;check if item is in current room
	LD D,(HL)							;number of location which contains our item 
	INC HL
	LD A,(CurrentRoomNr)
	CP D								;is item location and current location the same ?	
	JR Z,PrepareItems3					;is so, write item data

;if we are here - item isn't in current location
	PUSH HL
	LD HL,CurrentItemNr	
	INC (HL)							;increase item number
	POP HL	
	
	LD DE,4								;go to next item data
	ADD HL,DE
	JR PrepareItems2

;conditions accepted, writing item data	
PrepareItems3
	
	LD A,(CurrentItemNr)				;load to item table item number
	LD (IX+0),A

	LD B,(HL)
	INC HL
	LD C,(HL)							;BC loaded with item position
	LD (IX+1),C							;store item position
	LD (IX+2),B
	
	INC HL
	LD E,(HL)
	INC HL
	LD D,(HL)							;DE loaded with item graphics address
	LD (IX+3),E
	LD (IX+4),D							;store item tile address
	
;--------------	
;count and store, where player should be standing to be able to collect tihs item
;player item collecting position (address left upper corner of player sprite)= item position + item height - jetman height = itemposition+3-6=itemposition-3 		
		
	PUSH HL								;store item list address
	LD H,B
	LD L,C								;load item position to HL
	
	LD B,3 								;go 3 lines up
	LD A,L
CollectItemPosition1
	SUB 32								;go one line up
	JR NC,CollectItemPosition2			;no need to change segment
	PUSH AF
	LD A,H								;change segement if necessary
	SUB 8
	LD H,A
	POP AF
CollectItemPosition2	
	DJNZ CollectItemPosition1
	LD L,A
		
;item collect position counted in HL
;Store item data in room item table								
CollectItemPosition3
		
;load to item table item collecting position
	LD (IX+5),H
	LD (IX+6),L
	
;increase item nr to check next item  in next loop
	LD HL,CurrentItemNr
	INC (HL)
;increase number of items in current location
	LD HL,CurrentRoomItemsNr
	INC (HL)				
		
;Change IX to point in current location item table to next item
	LD DE,7
	ADD IX,DE
		
;this item drawing is finished, but there may be other items,so repeat routine	
	POP HL						;restore item list address	
	INC HL						;go to next item data
	JR PrepareItems2

;---------------------------
DrawItems
	LD HL,CurrentLocationItemTable
	
DrawItems2
	LD A,(HL)					;read item number
	OR A
	RET Z						;0 - end of items in current locations
	
	INC HL
	LD C,(HL)					;item position
	INC HL
	LD B,(HL)
	
	INC HL						;tile address
	LD E,(HL)
	INC HL
	LD D,(HL)
	
	PUSH HL
	LD L,C						;item position into HL
	LD H,B
	LD BC,3*256+3				;item size
	CALL DrawTile0				;draw item
	POP HL
	INC HL						;skip pickup position and go to next item in table
	INC HL	
	INC HL
	JR DrawItems2

;---------------------------	
PickAndDropItems

	LD A,(CurrentItem)
	PUSH AF								;storing item in inventory
	CALL PickItems						;picking item, if item was picked, its number is stored in inventory now
	
	POP AF
	LD B,A
	LD A,(CurrentItem)
	CP B								;is previous item from inventory and current the same?
										;Z=YES - no item was picked, just dropping item from inventory
										;NZ=NO - item was picked so just  maybe swapping items, or maybe just picking	
	JR Z,PickAndDropItems3

PickAndDropItems2
;item picked
	LD A,B								;old item
	OR A								;0=inventory empty before pickup
	JR Z,PickAndDropItems4				;is so, don't drop anything and go to menu refreshing
	
;swapping items, so go to dropping old item	
	CALL DropItems
	JR PickAndDropItems4
										

PickAndDropItems3
;just dropping item
	LD A,(CurrentRoomItemsNr)
	CP 2
	RET Z								;only 0,1 or 2 items in location are allowed
										;if there were more, then it would be a problem with screen refreshing
	
	LD A,B 								;old item into A
	OR A
	RET	Z								;nothing was held, nothing was picked so sothing will be dropped and no need for screen refresh	
	
	CALL DetermineChosenItem			;just dropping so write 0=lack of item into inventory
	XOR A
	LD (HL),A							;0 to inventory
	LD (CurrentItem),A
	
	CALL DropItems
	JR PickAndDropItems4	
									
PickAndDropItems4										
	;refresh current location and menu
	CALL DrawMenuItems
	CALL MenuSound
	
	XOR A
	LD (UpdateEnemy),A			;don't set enemy position to initial one
								;let him stay at his current position
						
								
	LD HL,(CurrentLocation)
	CALL DrawRoom
	CALL ChangeRoom2	
	RET

;---------------------------
PickItems	
 ;store item in inventory (if it exists)
 ;so picking new item and dropping old could be performed

 
;check if player is standing close to item
	LD HL,CurrentLocationItemTable+5	;pickup position of first item
PickItems2	
	LD A,(HL)
	OR A
	RET Z								;no more items in these location, item picking didn't happen
			
	LD A,(NewJetmanPos+1)
	CP (HL)								;compare H coordinate of jetman position and item pickup H position
	JR NZ,PickItems3					;not equal - check next item
	
	INC HL									
	LD A,(NewJetmanPos)					;compare L coordinate of jetman position and item pickup L position
	CP  (HL)
	JR Z,PickItems5						;picking up item
	INC A
	CP (HL)								;some tolerance in jetman position for picking item
	JR Z,PickItems5
	DEC A
	DEC A
	CP (HL)								;some tolerance in jetman position for picking item
	JR Z,PickItems5
	
	JR PickItems4						;items position is not equal to jetman position -> go check next item
	
;go to next item
PickItems3
	INC HL
PickItems4
	LD DE,6
	ADD HL,DE
	JR PickItems2
	
;-----------	
PickItems5
;pickup position confirmed, picking item
	LD DE,6
	SBC HL,DE					;go to item number
	LD A,(HL)
	
;remove item from current location (change its location to non-existing one)	
	LD B,A
	LD HL,ItemData-5
	LD DE,5	
PickItem6						;go to location data of our item
	ADD HL,DE
	DJNZ PickItem6
	
	LD B,255					;write non-existing location (255) to our item data
	LD (HL),B

;place item in inventory
	LD B,A
	CALL DetermineChosenItem
	
PickItem7	
	LD (HL),B					;store item number into inventory
	LD HL,CurrentItem
	LD (HL),B
	RET

;---------------------------	
DropItems
;number of item being dropped in B
;dropping item into location is writnig location data to item data in item table
	LD HL,ItemData-5
	LD DE,5
DropItems2
	ADD HL,DE
	DJNZ DropItems2				;find item data in item table
	LD A,(CurrentRoomNr)		
	LD (HL),A					;write location nr to item data
	
	
;find position of dropped item	
	LD DE,(NewJetmanPos)
	LD B,3						;go 3 lines down from jetman top
DropItems3						;(jetman is 6 lines high and item is 3 lines high)
	LD A,E
	ADD A,32
	LD E,A
	JR NC,DropItems4
	
	LD A,D						;next screen segment if necessary
	ADD A,8
	LD D,A
	
DropItems4	
	DJNZ DropItems3
	
;write item position
	INC HL
	LD (HL),D
	INC HL
	LD (HL),E
	RET
	
	
;---------------------------
DetermineChosenItem	
;set HL to point to 1st item if it is chosen or 2nd item if it is chosen
	LD HL,FirstItem
	LD A,(ItemSelection)
	OR A						;first item or second item
	RET Z
	INC HL
	RET


	
;---------------------------
SwitchChosenItem
;0 ->1, 1->0

	LD HL,ItemSelection				;switch selected item
	LD A,(HL)
	CPL
	LD (HL),A
	
	LD HL,CurrentItem
	LD B,(HL)
	INC HL							;go to other item
	LD A,(HL)
	LD (HL),B						;swap current item and other item
	DEC HL
	LD (HL),A
	
	CALL DrawItemSelection
	LD B,7
SwitchChosenItem2	
	PUSH BC
	CALL RocketSound
	POP BC
	DJNZ SwitchChosenItem2
	RET

;---------------------------
KillCurrentItem
	CALL DetermineChosenItem
	XOR A
	LD (HL),A
	LD (CurrentItem),A
	CALL DrawMenuItems
	RET


;------------------
CurrentItemNr .BYTE 0

CurrentLocationItemTable
;only 2 items in location are poissible
 REPT 2
 .BYTE 0						;item nr
 .WORD 0						;item draw position
 .WORD 0						;item tile address
 .WORD 0						;item pickup position (position of jetman where pick up is possible)
 ENDR
 .BYTE 0						;ending byte

;------------------	
ItemData
;data of objects positions in the game are stored here
;they are copied from initial items data every time, the game is begun
;comments show item number, byte shift from GameItem data address and item name

	.BYTE 0,0,0,0,0,0	;1		0			ScrewDriver
	.BYTE 0,0,0,0,0,0	;2		5			Saw
	.BYTE 0,0,0,0,0,0	;3		10			Key 1
	.BYTE 0,0,0,0,0,0	;4		15			Pliers
	.BYTE 0,0,0,0,0,0	;5		20			Pickaxe
	.BYTE 0,0,0,0,0,0	;6		25			Dynamite	
	.BYTE 0,0,0,0,0,0	;7		30			Detonator
	.BYTE 0,0,0,0,0,0	;8		35			Diskette
	.BYTE 0,0,0,0,0,0	;9		40			Torch
	.BYTE 0,0,0,0,0,0	;10		45			Key 2
	.BYTE 0,0,0,0,0,0	;11		50			Grenade
	.BYTE 0,0,0,0,0,0	;12		55			Food
	.BYTE 0,0,0,0,0,0	;13		60			Poison
	.BYTE 0,0,0,0,0,0	;14		65			Fuel
	.BYTE 0,0,0,0,0,0	;15		70			Fuse
	.BYTE 0,0,0,0,0,0	;16		75			Potion
	.BYTE 0,0,0,0,0,0	;17		80			Dog
	.BYTE 0,0,0,0,0,0	;18		85			Pump
	.BYTE 0,0,0,0,0,0	;19		90			Emiter
	.BYTE 0,0,0,0,0,0	;20		95			Key 3
	.BYTE 0,0,0,0,0,0	;21		100			Lever
	.BYTE 0,0,0,0,0,0	;22		105			Card
;------------------	
InitialItemData
;items and their initial positions

		
;screwdriver
	.BYTE 7				;room number
	.BYTE 80,120			;position
	.WORD ScrewdriverItem	;tile address
;saw		
	.BYTE 1*16+9
	.BYTE 72,175
	.WORD SawItem		
;key 1
	.BYTE 2*16+4
	.BYTE 80,110
	.WORD Key1Item
;pliers						
	.BYTE 6*16+4
	.BYTE 72,46
	.WORD PliersItem
;pickaxe
	.BYTE 6*16+1
	.BYTE 72,36
	.WORD PickaxeItem				
;dynamite
	.BYTE 6*16+6
	.BYTE 80,102
	.WORD TNTItem
;detonator
	.BYTE 7*16+1
 	.BYTE 72,163
 	.WORD DetonatorItem
;diskette		
 .BYTE 4*16+11
 .BYTE 72,227
 .WORD DisketteItem		
;torch
 .BYTE 1*16+5
 .BYTE 80,115
 .WORD TorchItem							
;key 2
 .BYTE 4*16+12
 .BYTE 72,177
 .WORD Key2Item
 ;grenade
 .BYTE 2*16+3
 .BYTE 80,118
 .WORD GrenadeItem
 ;food
 .BYTE 5*16+1
 .BYTE 80,112
 .WORD FoodItem
 ;poison
 .BYTE 30
 .BYTE 80,118
 .WORD PoisonItem		
 ;fuel
 .BYTE 6*16+5
 .BYTE 72,56
 .WORD FuelItem
 ;fuse
 .BYTE 2*16+2
 .BYTE 80,112
 .WORD FuseItem
 ;potion
 .BYTE 5*16+3
 .BYTE 72,163
 .WORD PotionItem
 ;dog
 .BYTE 1*16+2
 .BYTE 80,114
 .WORD DogItem
 ;water pump
 .BYTE 3*16+10
 .BYTE 80,123
 .WORD PumpItem
 ;emiter (for bridge)
 .BYTE 3*16+14
 .BYTE 72,118
 .WORD EmiterItem
 ;key 3		
 .BYTE 6*16+14
 .BYTE 72,250
 .WORD Key3Item
 ;lever		
 .BYTE 7*16+13
 .BYTE 80,122
 .WORD LeverItem
 ;card
 .BYTE 1*16+7
 .BYTE 80,118
 .WORD CardItem
 
				
 .BYTE 0				
;------------------				
ItemGraphics
ScrewdriverItem
	.BYTE	  16,16,16,16,16,16
	.BYTE	  0,  0,248,255,255,248,  0,  0
	.BYTE	  0,  2,  6,246,246,  6,  2,  0
	.BYTE	  0,254,  1,255,  1,255,254,  0
	
	.BYTE	  0,  0,  0,0,0,0, 69, 69,  6 
	
SawItem
	.BYTE	  16
	.BYTE	  0,  0,  0,  0,  1,  3,  7, 15
	.BYTE	 28, 60,126,248,252,224,240,192
	.BYTE	  0,  0,  1,  2,  6, 14, 30, 51
	.BYTE	 31, 63,127,254,255,248,252, 96
	.BYTE	224,  0,128,  0,  0,  0,  0,  0
	.BYTE	 49, 24, 12,  7,  3,  1,  0,  0
	.BYTE	128,192,192,192,192,192,  0,  0
	.BYTE	  16
	.BYTE	  0, 69, 69, 66, 69, 69, 66, 66,0
Key1Item
	.BYTE	  0,  0,  1,  2,  3,  2,  3,  2
	.BYTE	  0,  0,255,  0,127, 64, 64, 64
	.BYTE	  0,  0,248,  4,228, 52, 36, 52
	.BYTE	  3,  2,  1,  0,  0,  0,  0,  0
	.BYTE	127,  0,253,  9, 13,  9, 13,  9
	.BYTE	228,  4,248,  0,  0,  0,  0,  0
	.BYTE	  0,  0,  0,  0,  0,  0,  0,  0
	.BYTE	109,105, 13,233,237,233, 15,  0
	.BYTE	  16
	.BYTE	 70, 70, 70, 70, 70, 70,  0, 70,0
PliersItem
	.BYTE	 16
	.BYTE	 20, 54,119,119,119,119, 62, 20
	.BYTE	 16
	.BYTE	  0,  0,  0,  0,  1,  1,  1,  0
	.BYTE	 62,119,247,227,227,193,193,  0
	.BYTE	  0,  0,128,128,192,192,192,  0
	.BYTE	  3,  0,  3,  3,  3,  3,  3,  3
	.BYTE	193,  0,128,128,128,128,128,  0
	.BYTE	224,  0,224,224,224,224,224, 96
	.BYTE	  0, 69,  0, 69, 69, 69, 66, 66,66
	
PickaxeItem		
	.BYTE	  16
	.BYTE	  0,  0,252,127, 15,  3,  1,  2
	.BYTE	  0,  0,  0,128,192,224,240,240
	.BYTE	  0,  0,  0,  0,  0,  0,  1,  2
	.BYTE	  5, 15, 22, 44,120,208,160,192
	.BYTE	112, 56, 56, 24, 24, 24,  8,  0
	.BYTE	  5, 15, 30, 52,104,208,224, 64
	.BYTE	  16
	.BYTE	  16
	.BYTE	  0, 69, 69,  3,  3, 69,  3,  0,0
TNTItem
	.BYTE	  1,  2,  2,  0,  6,  4,  6,  4
	.BYTE	 17, 34, 34,  0,204,170,204,170
	.BYTE	 32, 64, 64,  0,192,128,192,128
	.BYTE	  0, 15,  8, 13, 13, 13, 15,  0
	.BYTE	  0,255,180,150,166,182,255,  0
	.BYTE	  0,224, 96,224,224,224,224,  0
	.BYTE	  6,  4,  6,  4,  6,  4,  6,  0
	.BYTE	170,204,170,204,170,204,170,  0
	.BYTE	192,128,192,128,192,128,192,  0
	.BYTE	  2, 66,  2,  1, 65,  1,  2, 66,2
DetonatorItem
	.BYTE	 61,125,125,  1,  1,  1,  1,  1
	.BYTE	188,190,190,128,128,128,128,128
	.BYTE	  16
	.BYTE	  0,255,128,191,191,175,159,191
	.BYTE	  0,255,  1,189,121,253,249,245
	.BYTE	  16
	.BYTE	187,183,191,191,190,149,128,255
	.BYTE	217,181,233,213,169, 85,  1,255
	.BYTE	 48,120, 72, 72, 73,207,134,  0
	.BYTE	 65,  1,  0, 66, 66,  0, 66, 66,65
	
	
DisketteItem
	.BYTE	255,128,191,165,191,191,128,128
	.BYTE	255,  0, 63, 42, 53, 63,  0,  0
	.BYTE	254,  2,242,182, 84,244,  6,  2
	.BYTE	128,128,128,128,128,128,128,136
	.BYTE	 56, 68,130,130,130, 68, 56, 16
	.BYTE	 10, 18, 10, 18, 10, 18, 42, 18
	.BYTE	144,136,144,128,128,128,255,  0
	.BYTE	 56, 56, 56, 56, 56, 16,255,  0
	.BYTE	 42, 82, 42, 82,170,  2,254,  0
	.BYTE	 65, 65,  1, 65, 65,  1, 65,  1,1
TorchItem
	.BYTE	 15, 16, 18, 21, 18, 17, 19, 23
	.BYTE	255,  0,170, 81,170,253,255,129
	.BYTE	224, 16,144, 80,148, 86,150,214
	.BYTE	  3, 26, 26, 26, 26, 26,  2, 23
	.BYTE	 60,122,245,251,253,255,126, 60
	.BYTE	214, 84, 80, 80, 80, 80, 80,144
	.BYTE	 21, 18, 21, 18, 21, 18, 16, 15
	.BYTE	129,254,124, 42, 85,170,  0,255
	.BYTE	208,144, 80,144, 80,144, 16,224
	.BYTE	 65, 65, 65, 65, 70, 65, 65, 65,65
Key2Item
	.BYTE	  16
	.BYTE	 15, 60, 56,120,124,127,127,127
	.BYTE	192,240,112,120,248,248,248,248
	.BYTE	 16
	.BYTE	 63, 63, 15,  7,  6,  6, 14,  6
	.BYTE	240,240,192,128,128,128,128,128
	.BYTE	  16
	.BYTE	 14, 14,  6, 14, 14,  7,  3,  0
	.BYTE	128,128,128,128,128,128,  0,  0
	.BYTE	 0, 70,  6, 0, 70,  6,  0, 70,6
GrenadeItem
	.BYTE	  16
	.BYTE	  0,  1,  1,  0, 11, 48, 99, 69
	.BYTE	224, 16, 16,224,248,  0, 88, 84
	.BYTE	  16
	.BYTE	138,138,150, 22,  0, 22, 22, 22
	.BYTE	 74,234,237,237,  1,237,237,237
	.BYTE	  16
	.BYTE	 22,  0, 22, 22, 10, 11,  5,  2
	.BYTE	237,  0,237,237, 74, 90,180,168
	.BYTE	  0, 68, 68, 0, 68,  4,  0, 68,4
FoodItem
	.BYTE	  0,  0,  0,  0,  0, 13,123, 15
	.BYTE	  0,  0,  0,  0,  0,253,219,191
	.BYTE	  0,  0,  0,  0,  0,240,190,112
	.BYTE	224,255,191,230,173,229,173,174
	.BYTE	  0,255,255,115,173,173,173,115
	.BYTE	 14,250,250, 58, 82, 82, 82, 34
	.BYTE	255,191,191, 95, 79, 32, 31,  0
	.BYTE	255,255,255,234,213,  0,255,  0
	.BYTE	210,162, 82,164, 68,  8,240,  0
	.BYTE	  7,  7,  7,  6,  6,  6,  6,  6,6
PoisonItem
	.BYTE	  0,  7,  2,  1,  1,  1,  1,  1
	.BYTE	  0,255,  2,  4, 20, 12, 20, 12
	.BYTE	  16
	.BYTE	  2,  4,  9, 19, 32, 33, 33, 33
	.BYTE	 22,  1,  4,  6,248,252, 36, 36
	.BYTE	  0,  0,128, 64,160, 96,160, 96
	.BYTE	 32, 32, 32, 33, 38, 34, 32, 31
	.BYTE	216,248,136,116,  3,  2,  0,255
	.BYTE	160, 96,160, 96, 32, 96, 32,192
	.BYTE	 69, 69,  0, 69, 69, 65, 69, 69,65
FuelItem
	.BYTE	  0, 15, 31, 48, 96, 71, 72, 83
	.BYTE	  0,128,192, 96,  0,254,  1,254
	.BYTE	  0,  0,  0,248,  0,112, 48,144
	.BYTE	 84, 20, 20, 21, 21, 21, 21, 21
	.BYTE	  0,254,124, 57,147,199,199,147
	.BYTE	 64, 32, 80, 80, 80, 80, 80, 80
	.BYTE	 21, 20, 20, 20, 19,  8,  7,  0
	.BYTE	 57,124,254,  0,255,  0,255,  0
	.BYTE	 80, 80, 80, 80,208, 32,192,  0
	.BYTE	 66, 66,  2, 66, 66,  2, 66, 66,2
FuseItem
	.BYTE	  16
	.BYTE	  0,  0,  0, 60, 82,122,126,  0
	.BYTE	  16
	.BYTE	  0,  0,  0,  0,  0,  0,  1,  3
	.BYTE	118,106, 86,106, 86,235,213,170
	.BYTE	  0,  0,  0,  0,  0,  0,128,192
	.BYTE	  3,  3,  3,  2,  3,  1,  0,  0
	.BYTE	 85,170, 85,170,  0,255,  0,255
	.BYTE	 64, 64, 64, 64,192,128,  0,  0
	.BYTE	  0,  5,  0, 71, 71,  7, 71, 71,7

PotionItem
	.BYTE	  16
	.BYTE	 60, 60,  0,255, 66, 90, 66, 66
	.BYTE	  16
	.BYTE	  0,  1,  2,  5, 10, 12, 10, 13
	.BYTE	161, 64,128,  0,  0,  0,  0, 85
	.BYTE	  0,128, 64, 32, 16, 16, 16, 80
	.BYTE	 10, 15, 10,  7, 11,  5,  2,  1
	.BYTE	170, 85,170, 85,170, 85,170,119
	.BYTE	176, 80,176, 80,176, 96,192,128
	.BYTE	  0, 71,  0, 71, 71, 71, 65, 65,65
	
DogItem
	.BYTE	  0,  0,  0,  0,  0,  0,  0, 48
	.BYTE	  0,  0,  0,  0,  0,  0,  1,  3
	.BYTE	  0,  0,  0,  0,  0,  0,192,144
	.BYTE	 64,128,128,193,255,111, 87,106
	.BYTE	  3,  2,  3,250,253,254,255,191
	.BYTE	 24,132, 20,158, 63, 63,158,192
	.BYTE	 53, 31, 14, 12, 12, 12, 14,  7
	.BYTE	 87,255,  7,  3,  3,  3,  3,  1
	.BYTE	128,128,  0,  0,  0,  0,128,192
	.BYTE	 66, 66, 66, 66, 66, 66,  2,  2,2
	
PumpItem
	.BYTE	  0,  1,  3,  7, 14, 12, 24, 24
	.BYTE	240,248,136,  0,  8,  8,  8,  0
	.BYTE	 16
	.BYTE	 52, 54, 99, 96, 64,192,128,128
	.BYTE	255,  0, 75, 11, 75, 11, 75, 11
	.BYTE	128,  0,  0,126,127,127,  7,  3
	.BYTE	  16
	.BYTE	 75, 11, 75, 11, 75, 75,  0,255
	.BYTE	  3,  0,  3,  3,  0,  0,  0,  0
	.BYTE	 69, 69,  0, 69, 69, 69,  5, 69,69

EmiterItem
	.BYTE	  16
	.BYTE	  16
	.BYTE	 32, 32, 32, 32, 32, 32, 32, 32
	.BYTE	  0,  0,  0, 14, 21, 26, 21,  0
	.BYTE	  16
	.BYTE	 32, 32, 32, 32,  0,112,112,  0
	.BYTE	127, 64,116,106,117,106,117,127
	.BYTE	255,  0,164, 82, 41,148, 74,255
	.BYTE	254,  2,146, 74, 34,146, 74,254
	.BYTE	  0,  0, 69, 66,  0, 69, 65, 65,65

Key3Item
	.BYTE	  1,  3,  7,  6,  6,  6,  3,  1
	.BYTE	255,255,  0,  0,  0,  0,128,255
	.BYTE	192,224,112, 48, 48, 48,224,192
	.BYTE	  16
	.BYTE	127,  0, 20, 20, 20, 20, 20, 20
	.BYTE	  16
	.BYTE	  16
	.BYTE	 20,212, 84,212, 84,212,212, 20
	.BYTE	  16
	.BYTE	 69, 69, 69,  0, 69,  0,  0, 69,0

LeverItem
	.BYTE 16
	.BYTE	128,128,192,192,224, 96, 96, 96
	.BYTE 16
	.BYTE 16
	.BYTE	 48, 48, 48, 48, 24, 24, 24, 24
	.BYTE 16
	.BYTE 16
	.BYTE	 12, 12, 12, 12,  6,  6,  6,  6
	.BYTE 16
	.BYTE	  0, 69,  0,  0, 69,  0,  0, 69,0
	

CardItem
	.BYTE	  0,  0, 31, 63, 63,127, 97,127
	.BYTE	  0,  0,255,255,255,248, 11,251
	.BYTE	  0,  0,240,248,248,  4,244, 52
	.BYTE	127, 97,127,127,100,127,127,127
	.BYTE	250, 74,250,251,138,248,255,255
	.BYTE	 20, 20, 20, 52, 20,  4,252,252
	.BYTE	  0,  0,  0,127,127, 63,  0,  0
	.BYTE	  0,  0,  0,255,255,255,  0,  0
	.BYTE	  0,  0,  0,252,252,248,  0,  0
	.BYTE	 69, 69, 69,  5,  5,  5, 65, 65,65
	