SetEnemy
;prepare enemy data for the first time when player enters new location
;HL points now to enemy data
;we need to copy this data to current screen enemy variables	
	LD DE,EnemyNr
	LD B,9
	LD A,(HL)
	LD (DE),A
	OR A
	RET Z								;0 means no enemy in this location, so no need to read more data	
	
	CP 7
	JP Z,SetBullets						;in some locations there are guns shooting bullets which are treated like a different enemy
		
CopyEnemyData
	LD A,(HL)
	LD (DE),A							;copying data
	INC HL
	INC DE
	DJNZ CopyEnemyData
	
;count some other enemy variables
	LD A,1
	LD (EnemyFrame),A
	
	LD A,(EnemyNr)
	LD HL,Enemy11-72-576			;(576 = size of one enemy data)
	LD DE,576
	LD B,A
CountEnemyAddress
	ADD HL,DE
	DJNZ CountEnemyAddress		
	LD (EnemyAddress),HL

;----------------
;find the order of animation frames of enemy and store it		
;enemy nr in A
CountEnemySequence
	CP 3
	JR Z,CountEnemySequence_B 		;propeller robot needs another sequence
	CP 5
	JR Z,CountEnemySequence_B 		;worm needs different sequence too
			
	CP 6							;yellow robot needs 2 sequences: A:going left B:going right	
	JR Z,CountEnemySequence_C
	
			
CountEnemySequence_A			
	LD HL,EnemySequence1-1 			;typical sequence, go through 8 frames and repeat from beginning
	LD A,25
	JR CountEnemySequence2
				
CountEnemySequence_B
	LD HL,EnemySequence2-1			;sequence for robot with propeller or worm, frames forth and back
	LD A,43
	JR CountEnemySequence2
	
CountEnemySequence_C				;yellow robot	
	LD A,(EnemyXSpeed)
	BIT 7,A 						;7th bit set= speed 255,254 or so -> going left	
	JR NZ,CountEnemySequence_A		;going left= sequence 1
	LD HL,EnemySequence1B-1 		;going right = sequence 2
	LD A,25
		
;sequence found	
CountEnemySequence2	
	LD (CurrentEnemySequence),HL	
	LD (SequenceFrames),A					
										
CountEnemyColor	
	LD HL,EnemyColorData-1
	LD A,(EnemyNr)
	ADD A,L
	LD L,A
	LD A,0
	ADC A,H
	LD H,A
	LD A,(HL)
	LD (EnemyColor),A	
			
 	LD HL,EnemyX
	LD  B,(HL) ;enemyx 
	INC  HL
	LD  C,(HL) ;enemyy 
	CALL  XYtoHL
	
 	PUSH HL
	LD  (NewEnemyPos),HL
 	LD (OldEnemyPos),HL
 	CALL CountEnemyAttrPos
 	LD  (NewEnemyAttrPos),HL
 	LD (OldEnemyAttrPos),HL
 	POP HL
	
;put into buffer addresses of each pixel line of enemy sprite
;to be used by drawing routine later
	PUSH HL
	LD DE,EnemyOldLineAdresses
	LD B,24
	CALL PrepareLineAddressesInBuffer
	POP HL
	
	LD DE,EnemyNewLineAdresses
	LD B,24
	CALL PrepareLineAddressesInBuffer
	
 	CALL PrepareEnemy
  	RET		

;---------------------------------------------
;put enemy sprite prepared for drawing into buffer
PrepareEnemy
	LD A,(EnemyFrame)			;count animation frame
	LD HL,(CurrentEnemySequence)
	LD B,A
PrepareEnemy1
	INC HL
	DJNZ PrepareEnemy1

	LD B,(HL)					;number of animation frame in B
	LD HL,(EnemyAddress)
	LD DE,72
PrepareEnemy2						
	ADD HL,DE
	DJNZ PrepareEnemy2			;start of enemy graphic data in HL
	
		
;put enemy sprite in buffer	
	EX DE,HL					;enemy sprite address IN DE	
	LD  HL, EnemySpriteBuffer
	LD  B,24  
	
 
EnemyIntoBuffer
	REPT 3
	LD A,(DE)
	LD  (HL),A 					;write one line to buffer
	INC L 						;next buffer address (no need of doing INC HL) 
 	INC  DE						;cause there is no posibility of carry) 
	ENDR
	
	LD  (HL),0 					; empty 4th column- right side of sprite 
	INC  L
	DJNZ EnemyIntoBuffer		;repeat 24 times

;rotate enemy in buffer
	LD  A,(EnemyRotation)
	LD  C,A                 	;number of pixels being shifted in C
	OR  A
	JR Z,ChangeEnemyFrame 		;if no rotation required, skip rotatating 
		

;set rotating parameter 
	LD  HL,RotateOption
	LD (HL),63					;when rotating left side of buffer is being filled with unlit pixels (SCF CCF(code 63)) 

RotateEnemy1
 LD  HL,EnemySpriteBuffer 		;start of rotated mask data 
 LD  B,24 						;number of lines  
 CALL  RotateRight 				;make one rotation 
 DEC  C
 JR  NZ, RotateEnemy1 			;make C rotations		
				
	
;change frame for next game cycle
ChangeEnemyFrame	
	LD DE,EnemyFrame
	LD A,(DE)
	INC A
	LD HL,SequenceFrames
	CP (HL)						;end of frame cycle?
	JR NZ,ChangeEnemyFrame2
	LD A,1						;start of frame cycle			
ChangeEnemyFrame2	
	LD (DE),A	
	RET	
	
;---------------------------------------	 
;drawing enemy
DisplayEnemy	

ClearEnemy
	LD HL,(OldEnemyPos)
	
	LD B,24;height in lines
	LD (StoreStack),SP			
	LD SP,EnemyOldLineAdresses		;start of line addresses
	XOR A							;fill with 0s

;clear graphics	
ClearEnemy1
	POP HL							;address of next line into HL
									
	LD (HL),A						;4 bytes in a line
	INC L							
	LD (HL),A				
	INC L
	LD (HL),A				
	INC L
	LD (HL),A				
	DJNZ ClearEnemy1
	LD SP,(StoreStack)

;clear attributes	
ClearEnemyAttr
	LD B,4							;B needs to be 3 when enemy et equal vertical position and moving only horizontal
	LD A,(EnemyY)
	AND 00000111b
	JR NZ,ClearEnemyAttr2           ;4 lines of attributes
	LD A,(EnemyYSpeed)
	OR A
	JR NZ,ClearEnemyAttr2
	
	DEC B							;only 3 lines of attributes		
	
ClearEnemyAttr2			
	LD HL,(OldEnemyAttrPos)
	LD A,71							;white ink on black paper
	LD DE,29	
ClearEnemyAttr3
	LD (HL),A
	INC L
	LD (HL),A
	INC L
	LD (HL),A
	INC L
	LD (HL),A						;one attribute line is finished

	ADD HL,DE 						;go to next line (29=32-3 already increased)
	DJNZ ClearEnemyAttr3	
			
;-----------	
DrawEnemy
	LD HL,EnemySpriteBuffer
	
	LD (StoreStack),SP
	LD SP,EnemyNewLineAdresses	;start of line addresses


;draw one line of background
		LD A,24				;height in lines
DrawEnemy1			
		POP DE				;address of next line into HL

;4 bytes in a line
		LDI					;load (DE) with (HL), increase HL,DE (and decrease BC which doesn't matter now)
		LDI
		LDI
		LDI
		DEC A
		JR NZ,DrawEnemy1
		
		LD SP,(StoreStack)
	

		
DrawEnemyAttr
	LD B,4						;B needs to be 3 when enemy at equal vertical position
	LD A,(EnemyY)
	AND 00000111b
	JR NZ,DrawEnemyAttr2
	DEC B		
	
DrawEnemyAttr2	
	LD A,(EnemyColor)
	LD HL,(NewEnemyAttrPos)
	LD DE,29
		
DrawEnemyAttr3
	LD (HL),A
	INC L
	LD (HL),A
	INC L
	LD (HL),A
	INC L
	LD (HL),A 			;one attribute line is finished
	ADD HL,DE 			;go to next line (29=32-3 already increased)
	DJNZ DrawEnemyAttr3	
	RET	
	
;----------------------------------------
;moving enemy
ChangeEnemyPos
;new position becomes old position 
	LD  HL,(NewEnemyPos)
	LD  (OldEnemyPos),HL
	
;put into buffer addresses of each pixel line of enemy old position
;to be used by drawing routine later
	LD DE,EnemyOldLineAdresses
	LD B,24
	CALL PrepareLineAddressesInBuffer
	

;new attributes become old attributes
	LD HL,(NewEnemyAttrPos)
	LD (OldEnemyAttrPos),HL					

;change coordinates
ChangeEnemyX		
	LD HL,EnemyX
	LD DE,EnemyXSpeed
	LD A,(DE)
	OR A
	JR Z,ChangeEnemyY			;no X speed=no need to change anything
	LD B,(HL)
	ADD A,B						;add X speed to X coordinate
	LD (HL),A					;store new X position

;rotation
	PUSH AF
	AND 00000111b
	LD (EnemyRotation),A		;store rotation
	POP AF
	CALL CheckInvertXSpeed		;edge reached, speed = -speed ?
	
			
ChangeEnemyY					
	LD HL,EnemyY
	LD DE,EnemyYSpeed
	LD A,(DE)
	OR A
	JR Z,ChangePositionEnd		;no Y speed=no need to change anything
	LD B,(HL)				
	ADD A,B						;add Y speed to Y coordinate
	LD (HL),A					;store new Y position
	CALL CheckInvertYSpeed		;edge reached, speed = -speed ?
	
	
ChangePositionEnd		
	LD HL,EnemyX				;go to enemy X				
	LD B,(HL)
	INC HL
	LD C,(HL)					;enemy Y
	CALL XYtoHL
	LD (NewEnemyPos),HL			;storin new position
	
;put into buffer addresses of each pixel line of enemy sprite
;to be used by drawing routine later
	PUSH HL
	LD DE,EnemyNewLineAdresses
	LD B,24
	CALL PrepareLineAddressesInBuffer
	POP HL
	
	CALL CountEnemyAttrPos
	LD (NewEnemyAttrPos),HL	
	RET

;---------------------------
CheckInvertXSpeed
;check if speed should be inverted (when enemy reaches edge of its path)
	LD B,A 						;B contains enemy X position	
	LD A,(EnemyEdgeLeft)
	CP B
	JR Z,InvertSpeedLeftEdge			
	LD A,(EnemyEdgeRight)
	CP B
	JR Z,InvertSpeedRightEdge	
	RET
	
InvertSpeedLeftEdge
;check if change animation sequence for enemy
 LD A,(EnemyNr)
 CP 6						;check if yellow robot
 JR NZ, InvertSpeed
 LD HL,EnemySequence1B
 LD (CurrentEnemySequence),HL						
 JR InvertSpeed	
	
InvertSpeedRightEdge
 LD A,(EnemyNr)
 CP 6						;check if yellow robot
 JR NZ,InvertSpeed
 LD HL,EnemySequence1
 LD (CurrentEnemySequence),HL
 JR InvertSpeed

;------------ 	
CheckInvertYSpeed		
	LD B,A	
	LD A,(EnemyEdgeTop)
	CP B
	JR Z,InvertSpeed			
	LD A,(EnemyEdgeBottom)
	CP B
	JR Z,InvertSpeed	
	RET
	
;------------ 	
InvertSpeed
	LD A,(DE)
	CPL
	INC A
	LD (DE),A		
	RET		
		
	
;----------
CountEnemyAttrPos
	LD  A,H
	AND  11111000b
	LD  H,A
	LD  A,80
	SRL  H
	SRL  H
	SRL  H
	ADD  A,H
	LD  H,A 
	RET
 

;--------------------------------
PrepareLineAddressesInBuffer
;store in chosen buffer address of first byte in each pixel line of the sprite
;to be used later by drawing routine
;HL: screen address of left upper corner
;DE: buffer start
;B:  number of lines
	LD A,L
	LD (DE),A
	INC DE
	LD A,H
	LD (DE),A
	INC DE
	CALL OnePixelLineDown
	DJNZ PrepareLineAddressesInBuffer
	RET
	
;-------------
OnePixelLineDown
;requires HL as screen address

	INC H 							;go to new pixel line
	LD A,H
	AND 00000111B
	OR A 							;h=0 -> going to new character line
	RET NZ							;new line belongs to the same character line
	
	LD A,L ;going to new character line
	ADD A,32
	LD L,A
	RET C							;going to new screen segment, if e.g h was 71, now it is 72
	
	LD A,H
	SUB 8
	LD H,A							;decrease h if we are in the same screen segment
	RET

;---------------
OneCharacterLineDown
;HL: screen position
;go one character line down
	LD A,L							
	ADD A,32
	LD L,A
	RET NC
	LD A,H
	ADD A,8
	LD H,A
	RET
	
;--------------------------------------
SetBullets
;HL points to locations enemy data
	LD DE,Bullet1L
	INC HL					;1st bullet initial position
	LD A,(HL)				;L
	LD (DE),A
	INC DE
	LD A,80					;H
	LD (DE),A
	
	INC HL					;2nd bullet initial position
	INC DE
	LD A,(HL)
	LD (DE),A				;L
	INC DE
	LD A,80
	LD (DE),A				;H
	
	INC DE
	XOR A
	LD (DE),A				;bullet free time=0 - bullets instantly appear
	RET	

	.WORD #acaB
DisplayBullets	
;animate bullets which appear on a few locations
	LD HL,BulletFreeTime
	LD A,(HL)
	OR A
	JR Z,DisplayBullets1	;no free time,display bullets
	
	DEC (HL)				;decrease free time left
	RET
	
DisplayBullets1
;clear bullets at old position
	LD HL,(Bullet1L)		;first bullet
	CALL ClearBullet
	
	LD HL,(Bullet2L)		;second bullet (if it exists)
	LD A,L
	OR A
	CALL NZ,ClearBullet
	
	
;change bullets position
DisplayBullets2	
	LD HL,(Bullet1L)
	CALL ChangeBulletPosition	
	LD (Bullet1L),HL
	
	LD HL,(Bullet2L)
	LD A,L
	OR A
	CALL NZ,ChangeBulletPosition	
	LD (Bullet2L),HL
	
;draw bullets at new position
	LD A,(BulletFreeTime)	;if bullet reached end, don't draw it in this loop repeat
	OR A
	RET NZ

	LD DE,(Bullet1L)		;1st bullet
	CALL DrawBullet
	
	LD DE,(Bullet2L)		;2nd bullet (if it exists)
	LD A,E
	OR A
	CALL NZ,DrawBullet
	RET
	
;--------
ChangeBulletPosition	
	CALL BulletOneLineDown
	LD A,L
	CP 160					;end of bullet movement?
	RET C
;going back up
	LD A,L
	SUB 160
	LD L,A
	LD H,80
	
	LD A,30					;some free time after this bullet
	LD (BulletFreeTime),A
	RET

;--------
ClearBullet	
	LD B,8
	LD C,0
	XOR A
ClearBullet2
	LD (HL),C
	INC L
	LD (HL),C
	DEC L
	
	CALL BulletOneLineDown
	
	DJNZ ClearBullet2 
	RET	

;--------
DrawBullet	
	LD HL,Bullet
	LD BC,16		;8 lines but 2 LDIs-16 repeats
	
DrawBullet2
	LDI				;copy 2 bytes
	LDI			
	DEC E			;go to start of line
	DEC E
;go one pixel line down	
	INC D
	LD A,D
	CP 88
	JR NZ,DrawBullet3
	
;change character line if necessary
	LD D,80
	LD A,E
	ADD A,32
	LD E,A	
	
DrawBullet3
	LD A,B
	OR C
	JR NZ,DrawBullet2			
	RET
	
;--------
BulletOneLineDown
	INC H
	LD A,H
	CP 88
	RET NZ
	
	LD H,80
	LD A,L
	ADD A,32
	LD L,A
	RET
	
	
Bullet
	.BYTE	  1,192,  3,224,  6,176,  5, 80
	.BYTE	  6,144,  5, 16,  2, 32,  1,192

;--------------------------------------				 			
EnemySequence1			.BYTE 1,1,1,2,2,2,3,3,3,4,4,4,5,5,5,6,6,6,7,7,7,8,8,8
EnemySequence1B  		.BYTE 8,8,8,7,7,7,6,6,6,5,5,5,4,4,4,3,3,3,2,2,2,1,1,1		
													
EnemySequence2 			.BYTE 1,1,1,2,2,2,3,3,3,4,4,4,5,5,5,6,6,6,7,7,7,8,8,8
		  				.BYTE 7,7,7,6,6,6,5,5,5,4,4,4,3,3,3,2,2,2
		  				
EnemyColorData 			.BYTE 69,70,67,71,68,6	;colors of different enemies	  				


	



			
