;---------TEXT-----------
TypeText	
;HL; contains position of text on screen
;DE contains text address in memory
;BC is used
		
;the text is compressed,each letter only takes 5 bytes (32 combinations) 
;for example AAA text is stored without compression as 1,1,1
;after compression it will take 2 bytes and will look in binary

; 00001|000  01|0|00001 
;and in decimal 8,65
;the bit in the middle of second byte is not used

	LD (TextLineAddress),HL
	
	LD A,71					;Default text color is white on black
	LD (TextColor),A
	XOR A					
	LD (LetterNr),A	
		
TypeText1	
	PUSH HL
	CALL DepackLetter		;read letter from compressed data and put it in A
	POP HL
	
	OR A
	RET Z 					;end of text if zero
	
	LD C,A					;store letter
	
	CP 29					;check if should go to new line
	JR Z,TextNewLine
	
	CP 30					;check if color change
	JR Z,TextColorChange
	
	CP 31					;check for extended symbols (32-62) coded with 31 and number 1-31
	JR Z, TextExtendedSymbols
		
TypeText2	
	PUSH HL					;paint letter attribute
	LD A,80
	SRL H
	SRL H
	SRL H
	ADD A,H
	LD H,A
	LD A,(TextColor)
	LD (HL),A
	POP HL
	
	
	
;draw a letter
	LD A,C					;restore letter code
	LD BC,Letters-8			;start of letters tiles
	
;count address of letter
	SLA A
	SLA A
	SLA A					;A=A*8 (with carry)to count adress of letter		
	
	PUSH HL
	LD HL,0
		
	LD L,A
	LD A,0
	ADC A,H	
	LD H,A					;HL=A*8	
	ADD HL,BC
	LD B,H
	LD C,L					;BC loaded with current letter tile address
	POP HL
		

	PUSH HL
	PUSH DE
	LD E,8
	
TypeText3
	LD A,(BC)				;read letter graphical data
	LD (HL),A				;and print it in screen		
	INC H
	INC BC					;go to next byte
	DEC E
	JR NZ, TypeText3
	
	POP DE
	POP HL

;go to next letter			
	INC L					;next character on the screen
	JR TypeText1
	
;-------	
TextNewLine
;go one character line down	with text
	LD HL,(TextLineAddress)			;beginning of current line in HL
	CALL OneCharacterLineDown		;count address of one line down and place it in HL
	LD (TextLineAddress),HL			;update value
	JR TypeText1					;return to letter printing 

;-------	
TextColorChange
	PUSH HL
	CALL DepackLetter				;read new color
	OR 01000000B					;(colors are bright)
	LD (TextColor),A				;and store it
	POP HL
	JR TypeText1

;-------	
TextExtendedSymbols
	PUSH HL
	CALL DepackLetter				;read next byte
	POP HL
	ADD A,31						;next sign symbol is from 32 to 62 now	
	LD C,A							;this symbol is latter read from C
	JR TypeText2


;-----------------
DepackLetter
;DE points to current byte in compressed data
;HL and B are used
	LD HL,LetterNr
	LD A,(HL)
	AND 00000011B			;A=0-2
	
	OR A					;3 bytes are packed into 2 bytes
	JR Z,DepackLetter1		;we must check if we deal now with 1st, 2nd or 3rd byte
	CP 1
	JR Z,DepackLetter2
	CP 2
	JR Z,DepackLetter3
	
	
	 
DepackLetter1			; 00001|000  01|0|00001 
						; -----
							
	LD A,(DE)				;read byte of compressed data
	AND 11111000B			
	SRL A					;rotate right three timwa
	SRL A	
	SRL A					;letter code in A
	INC (HL)				;change leter number
	RET
	
DepackLetter2			; 00001|000  01|0|00001
						;       ---  --
							
	LD A,(DE)				;read byte of compressed data
	AND 00000111B			;three bits from first compressed byte
	SLA A					;rotate left 2 times
	SLA A					
		
	LD B,A					;store in B
	INC DE					;next compressed byte
	LD A,(DE)
	AND 11000000B
	SRL A
	SRL A					
	SRL A					
	SRL A
	SRL A
	SRL A					

	OR B					;letter code in A					
	INC (HL)				;change leter number
	RET
	
DepackLetter3				; 00001|000  01|0|00001
							;      			  -----

				                					
	LD A,(DE)				;read byte of compressed data
	AND 00011111B			;letter code in A	
	INC DE					;next compressed byte			

	LD B,0
	LD (HL),B				;change leter number
	RET
	
	
;--------------
TextColor				.BYTE 0
TextLineAddress  		.WORD 0
LetterNr				.BYTE 0		;value 0-3, every 3 bytes sotre 4 letter and this number tells us which letter 
	
								
;-------------------------------										
TypeMessage
;draw message,play sound and wait for key to clear message
	;A: number of message
		
;read data from message matrix
	LD B,A
	LD HL,MessageMatrix-6	
	LD DE,6	
FindMessageStart		
	ADD HL,DE
	DJNZ FindMessageStart		;find start of message data
		
	LD B,(HL)					;read message data	
	INC HL
	LD C,(HL)					;box size in BC
	INC HL
	LD E,(HL)
	INC HL			
	LD D,(HL)					;text address in DE
	INC HL
	PUSH DE
	LD D,(HL)
	INC HL
	LD E,(HL)
	EX DE,HL					;screen position in HL
	POP DE						;restore text address in DE
								
	CALL Textbox				;type text message
	
	;Now wait for pressing fire  clear the text
	
	
	
	CALL MenuSound
	
TypeMessage2	
	CALL GetPlayerInput
	BIT 4,A
	JR Z,TypeMessage2
	
	LD B,30	
TypeMessage3	
	HALT
	DJNZ TypeMessage3	
	
;refresh current location	
	XOR A
	LD (UpdateEnemy),A			;don't set enemy position to initial one
								;let him stay at his current position
	LD HL,(CurrentLocation)
	CALL DrawRoom
	CALL ChangeRoom2			;forget old jetman background and draw him again
					
	RET
	

	
;-----------------------
Textbox
;draw a textbox (border and text inside)
	;HL: left upper text box corner
	;BC: size,B=width,C=height
	;DE: memory address of text
		
	PUSH HL
	PUSH DE
	CALL DrawBorder				;draw border around text
	POP DE
	POP HL
	CALL OneCharacterLineDown	;currrent HL points to border, text begins one line lower
	INC L						;first collumn is border,text begins in next collumn
	CALL TypeText
	RET 



;----------LETTERS---------------
Letters
	.BYTE	  0, 62, 99,127, 99, 99,  0,  0;A 1
	.BYTE	  0,126, 99,126, 99,126,  0,  0;B 2
	.BYTE	  0, 63, 96, 96, 96, 63,  0,  0;C 3
	.BYTE	  0,126, 99, 99, 99,126,  0,  0;D 4
	.BYTE	  0,127, 96,126, 96,127,  0,  0;E 5
	.BYTE	  0,127, 96,126, 96, 96,  0,  0;F 6
	.BYTE	  0, 63, 96,103, 99, 63,  0,  0;G 7
	.BYTE	  0, 99, 99,127, 99, 99,  0,  0;H 8
	.BYTE	  0,126, 24, 24, 24,126,  0,  0;I 9
	.BYTE	  0,  6,  6,  6,  6,124,  0,  0;J 10
	.BYTE	  0, 99,102,124,102, 99,  0,  0;K 11
	.BYTE	  0, 96, 96, 96, 96,126,  0,  0;L 12
	.BYTE	  0, 99,119,127,107, 99,  0,  0;M 13
	.BYTE	  0,115,123,111,103, 99,  0,  0;N 14
	.BYTE	  0, 62, 99, 99, 99, 62,  0,  0;O 15
	.BYTE	  0,126, 99, 99,126, 96,  0,  0;P 16
	.BYTE	  0, 62, 97,101, 99, 62,  0,  0;Q 17
	.BYTE	  0,126, 99, 99,126, 99,  0,  0;R 18
	.BYTE	  0, 62, 96, 62,  3,126,  0,  0;S 19
	.BYTE	  0,126, 24, 24, 24, 24,  0,  0;T 20
	.BYTE	  0, 99, 99, 99, 99, 62,  0,  0;U 21
	.BYTE	  0, 99, 99, 54, 28,  8,  0,  0;V 22
	.BYTE	  0, 99, 99,107,127, 54,  0,  0;W 23
	.BYTE	  0, 99, 54, 28, 54, 99,  0,  0;X 24
	.BYTE	  0, 99, 99, 63,  3, 62,  0,  0;Y 25
	.BYTE	  0,127, 12, 24, 48,127,  0,  0;Z 26
	.BYTE	  0,  0,  0,  0,  0,  0,  0,  0;SPACE 27
	.BYTE	  0,  0,  0, 32,112, 32,  0,  0;. 28
	.BYTE	  0,  0,  0,  0,  0,  0,  0,  0;GO TO NEW LINE 29
	.BYTE	  0,  0,  0,  0,  0,  0,  0,  0;CHANGE COLOR 30
	.BYTE	  0,  0,  0,  0,  0,  0,  0,  0;EXTENDED SIGN PREFIX 31
	
	.BYTE	  0,  0,  0, 96, 96, 64,128,  0;, 32 (CODE 31 1)
	.BYTE	  0,  0, 12, 24, 16,  0,  0,  0;' 33 (CODE 31 2)
	.BYTE	  0, 60, 78, 28,  0, 24,  0,  0;? 34 (CODE 31 3)
	.BYTE	  0,  0,  0,  0,109,109,  0,  0;... 35 (CODE 31 4)
	.BYTE	  0, 96, 96,120, 96,126,  0,  0; 36 (CODE 31 5)
	.BYTE	  0,96,96,96,0,96,0,0,0        ;! 37 (CODE 31,6)
	
;--------------
MessageMatrix
	.BYTE 31,11			;message box size (BC)
	.WORD Note1			;text address (DE)
	.BYTE 72,1			;screen position (HL)
	
	.BYTE 32,16		;2	
	.WORD Note2			
	.BYTE 64,192		
	
	.BYTE 29,14		;3	
	.WORD Note3			
	.BYTE 64,226
	
	.BYTE 28,13		;4	
	.WORD Note4			
	.BYTE 64,226
	
	.BYTE 13,3		;5	
	.WORD DoorOpenText
	.BYTE 64,224
	
	.BYTE 23,3		;6	
	.WORD FuseboxOpenText
	.BYTE 64,224
	
	.BYTE 22,6		;7	
	.WORD FuseReplaceText
	.BYTE 64,224
	
	.BYTE 15,3		;8	
	.WORD AccessDeniedText 
	.BYTE 64,224
	
	.BYTE 21,3		;9	
	.WORD FeelBetterText 
	.BYTE 64,224
	
	.BYTE 28,6		;10
	.WORD DogOpenDoorText
	.BYTE 64,224
	
	.BYTE 27,5		;11
	.WORD DogEatFoodText
	.BYTE 64,224
	
	.BYTE 31,4		;12
	.WORD DogMeetText
	.BYTE 64,224
	
	.BYTE 24,4		;13
	.WORD CutBranchText
	.BYTE 64,224
	
	.BYTE 31,4		;14
	.WORD PickaxeBreakWallText
	.BYTE 64,224
	
	.BYTE 30,5		;15
	.WORD LeverPushCartText
	.BYTE 64,224
	
	.BYTE 25,4		;16
	.WORD FillFuelText
	.BYTE 64,224
	
	.BYTE 19,3		;17
	.WORD CutCableText
	.BYTE 64,224
	
	.BYTE 24,3		;18
	.WORD UseLiftText
	.BYTE 64,224
	
	.BYTE 29,3		;19
	.WORD TooDarkText
	.BYTE 64,224
	
	.BYTE 32,4		;20
	.WORD PoisonKillPlantText
	.BYTE 64,224
	
	.BYTE 21,3		;21
	.WORD DoorJammedText
	.BYTE 64,224
	
	.BYTE 29,3		;22
	.WORD GrenadeDoorText
	.BYTE 64,224
	
	.BYTE 14,3		;23
	.WORD OutOfPowerText
	.BYTE 64,224
	
	.BYTE 21,4		;24
	.WORD DiskAcceptedText
	.BYTE 64,224
	
	.BYTE 32,5		;25
	.WORD UseEmitterText
	.BYTE 64,224
	
	.BYTE 28,4		;26
	.WORD DestroyRocksText
	.BYTE 64,224
	
	.BYTE 26,3		;27
	.WORD PumpWaterText
	.BYTE 64,224
	
	.BYTE 25,3		;28
	.WORD NotLeaveYetText
	.BYTE 64,224
	
	
	
		
;--------------TEXTS-------------------
Note1
 .BYTE 241,78,125,5,239,94,61,200,13,27,14,196,76,195,125,133,150,95,53,8,76,219,131,1,25,93,109,83,166,194,46,212,65,91,48,77,125,83,219,89,146,65
 .BYTE 34,65,119,72,73,5,125,84,231,69,177,82,205,8,75,135,218,83,220,85,73,84,218,5,145,92,237,197,221,201,99,27,164,153,221,15,217,193,162,5,150,205
 .BYTE 124,133,234,78,51,210,104,84,75,206,227,213,150,210,44,197,12,131,70,215,75,12,232,133,220,212,124,133,38,212,126,207,133,9,34,83,92,220,0

Note2
 .BYTE 241,78,125,5,241,219,239,84,66,83,220,12,8,197,218,83,217,137,99,5,38,215,77,8,236,197,29,82,77,25,220,217,157,5,108,219,186,9,26,27,153
 .BYTE 69,110,212,127,66,46,207,129,82,13,9,123,129,102,193,101,8,125,71,70,206,125,29,8,212,77,133,231,77,204,137,9,9,11,147,221,197,145,91,157
 .BYTE 82,43,25,236,1,144,78,122,68,216,66,125,84,221,8,42,82,220,18,77,129,30,92,234,15,190,196,73,27,162,5,206,193,99,27,34,83,152,80,40,82,248,221
 .BYTE 237,197,219,65,33,91,60,133,13,27,132,143,60,133,156,219,13,29,75,134,126,210,40,207,177,82,75,135,231,80,146,67,43,5,156,219,152,201,43,148,73
 .BYTE 137,30,196,13,1,237,197,145,91,132,133,153,82,177,68,224,0
 
Note3
 .BYTE 241,78,125,5,241,221,232,146,173,21,159,193,125,82,217,15,63,193,51,213,113,27,155,205,47,72,171,65,118,194,123,133,159,29,185,91,17,76,73,86,46,206
 .BYTE 125,219,162,1,166,212,65,93,152,201,43,148,76,212,158,215,44,133,221,137,29,9,108,219,121,157,162,5,221,133,150,91,153,67,172,137,166,91,158,83,161
 .BYTE 77,237,8,46,91,28,133,13,5,39,29,77,27,185,78,166,205,9,27,11,132,218,201,99,5,39,69,177,82,203,206,47,29,115,215,218,84,218,83,220,85,73,84,216,149
 .BYTE 166,215,46,205,172,212,233,9,152,82,110,201,166,195,123,80,97,84,43,25,224,18
 
Note4
 .BYTE 241,78,125,5,241,221,235,200,219,143,249,159,55,198,237,8,46,211,40,213,146,84,206,211,204,212,43,91,64,83,232,87,10,197,119,29,162,5,153,91,153,78,164
 .BYTE 153,217,18,122,68,158,215,75,12,234,201,99,27,45,133,150,66,121,25,231,73,216,193,118,206,126,204,123,135,44,155,66,68,46,193,113,29,44,195,12,5,231
 .BYTE 80,144,89,217,143,150,207,172,155,155,213,100,219,11,153,19,196,207,87,67,219,145,65,36,219,77,28,232,14

DoorOpenText
 .BYTE 35,207,150,207,129,78,41,0

FuseboxOpenText  
 .BYTE 53,83,40,143,198,195,125,133,150,210,43,79,177,68,0

FuseReplaceText
 .BYTE 53,83,46,210,44,12,8,197,39,93,157,80,131,25,219,133,165,207,146,219,53,76,102,93,124,5,144,84,75,206,11,0
 
AccessDeniedText 
 .BYTE 8,195,44,211,217,5,114,69,32,29
 
FeelBetterText
 .BYTE 203,213,217,133,43,27,17,84,161,82,219,143,184,0
 
DogOpenDoorText 
 .BYTE 162,5,217,15,62,195,144,87,100,219,171,132,44,155,65,65,182,93,157,5,43,27,56,84,46,193,113,27,132,133,156,197,159,66,173,20,123,155,123,155,162,5
 .BYTE 219,212,65,82,220,201,33,92,237,8,46,199,13,5,220,204,125,204,206,210,76,197,159,0
 
DogEatFoodText
 .BYTE 35,199,217,65,164,219,51,207,38,193,113,27,17,67,123,69,159,70,146,69,113,12,207,8,46,215,11,148,158,212,126,199,127,87,77,8,222,79,175,0
 
DogMeetText
 .BYTE 162,9,158,196,121,219,76,219,52,137,58,20,43,133,38,193,113,29,187,206,248,148,216,76,99,215,222,79,174,212,126,199,45,27,27,15,153,82,0
 
CutBranchText
 .BYTE 203,213,216,204,40,82,41,27,128,83,152,71,46,194,207,67,173,20,75,135,221,8,46,194,144,78,26,27,121,134,6
 
PickaxeBreakWallText
 .BYTE 130,67,88,88,46,194,145,65,92,219,40,83,75,25,221,8,147,213,58,29,14,195,149,77,19,5,38,215,11,12,0
 
LeverPushCartText
 .BYTE 97,86,44,155,58,86,44,219,14,199,123,196,220,21,154,27,163,219,15,67,12,148,221,200,72,200,220,149,154,5,158,196
 .BYTE 125,206,221,201,162,29,14,212,145,77,43,132,125,83,220,208,41,68,0
 
FillFuelText
 .BYTE 203,213,217,137,99,5,38,212,65,91,24,78,221,201,162,29,156,1,25,91,53,69,96,2
 
CutCableText
 .BYTE 203,213,216,213,166,212,65,91,24,66,97,64
 
UseLiftText
 .BYTE 73,27,24,82,38,193,29,9,176,84,44,219,98,70,160,29
 
TooDarkText
 .BYTE 77,27,76,219,163,207,217,1,146,219,163,219,59,219,75,147,73,5,1
 
PoisonKillPlantText
 .BYTE 27,206,33,78,153,68,220,15,76,207,118,194,172,142,158,212,68,143,169,200,236,208,74,217,220,12,11,148,1
 
DoorJammedText
 .BYTE 162,9,158,196,123,210,218,83,218,129,107,69,32,0
 
GrenadeDoorText
 .BYTE 60,133,112,68,46,194,96,83,166,196,44,212,147,217,158,196,123,210,0
 
OutOfPowerText
 .BYTE 125,84,219,198,220,15,185,82,6
 
DiskAcceptedText
 .BYTE 34,83,94,193,24,197,133,5,39,68,123,210,216,67,25,83,158,199,144,78,161,68,0
 
UseEmitterText
 .BYTE 43,73,165,5,150,212,172,142,158,207,49,155,96,83,44,147,216,78,39,67,145,65,161,83,219,65,59,133,162,67,216,146,73,7,46,193,28
 .BYTE 143,156,221,162,5,221,193,161,82,0
 
DestroyRocksText
 .BYTE 65,65,182,91,19,213,97,5,148,219,12,133,216,210,172,200,41,29,163,219,37,83,166,201,118,197,196,12,124,201,123,157,1
 
PumpWaterText
 .BYTE 203,213,220,21,108,5,38,207,173,27,162,5,221,193,161,82,0
 
NotLeaveYetText 
 .BYTE 203,213,220,200,125,76,35,159,21,27,97,65,177,91,201,84,0